summaryrefslogtreecommitdiff
path: root/ace/Process_Manager.h
diff options
context:
space:
mode:
Diffstat (limited to 'ace/Process_Manager.h')
-rw-r--r--ace/Process_Manager.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/ace/Process_Manager.h b/ace/Process_Manager.h
index ce58be467fd..a16abbb3eac 100644
--- a/ace/Process_Manager.h
+++ b/ace/Process_Manager.h
@@ -79,8 +79,8 @@ public:
// Block until there are no more processs running or <timeout>
// expires. Returns 0 on success and -1 on failure.
- int kill (pid_t, int signum);
- // Kill a single process.
+ int terminate (pid_t pid);
+ // Terminate a single process with id <pid>.
int remove (pid_t pid);
// Remove process <pid> from the table. This is typically called by